@@ -1,4 +1,5 @@
 from django.db import models
+from django.contrib.auth import get_user_model
 from django.utils.timezone import now
 from django.contrib.auth.models import User, Group
 
@@ -15,7 +16,7 @@ class Token(models.Model):
 	created_at = models.DateTimeField(verbose_name='Дата и время создания', default=now)
 	valid_until = models.DateTimeField(verbose_name='Срок годности до', default=time_slice)
 	revoked = models.BooleanField(verbose_name='Отозван', default=False)
-	user = models.ForeignKey(User, on_delete=models.DO_NOTHING, verbose_name='Пользователь')
+	user = models.ForeignKey(get_user_model(), on_delete=models.DO_NOTHING, verbose_name='Пользователь')
 	
 	def __str__(self):
 		return '{} ({})'.format(str(self.user.username), str(self.created_at))
